.. image:: images/logo.png

-------------------------------------

Overview
---------

**FracAbility** is a Python toolbox that can be used to analyse fracture networks in digitalized rock
outcrops.

These are the main features available :

- **Shapefile importing support**


- **Rapid topology analysis and identification of I,Y,X and U nodes**


- **Fracture network backbone(s) identification**


- **Statistical analysis tools:**
    + Empirical CDF and SF calculation
    + Distribution fitting
    + Statistical model testing


- **Plotting tools:**
    + Network objects plotting using matplotlib or vtk
    + Ternary node plot
    + Rose diagram
    + Statistical plotting


The name FracAbility recalls the `reliability <https://github.com/MatthewReid854/reliability/tree/master>`_
library that inspired and helped in the creation of this project.

Documentation contents
-----------------------

Quickstart & Theory
~~~~~~~~~~~~~~~~~~~

.. toctree::
  :maxdepth: 2

  Quickstart
  Introduction to fracture network analysis
  Recommended resources

Tutorials
~~~~~~~~~~~~~~~~~~~


.. toctree::
  :maxdepth: 2
  :glob:

  Tutorial reference

API
~~~~~~~~~~~~~~~~~~~


.. toctree::
  :maxdepth: 2

  API reference

Glossary
~~~~~~~~~~~~~~~~~~~

.. toctree::
  :maxdepth: 2

  Glossary



Library status information
--------------------

.. |pypi| image:: https://img.shields.io/pypi/v/fracability.svg?logo=python&logoColor=white
   :target: https://pypi.org/project/pyvista/

.. |conda| image:: https://img.shields.io/conda/vn/conda-forge/fracability.svg?logo=conda-forge&logoColor=white
   :target: https://anaconda.org/conda-forge/pyvista

.. |stars| image:: https://img.shields.io/github/stars/gbene/fracability.svg?style=social&label=Stars
   :target: https://github.com/gbene/fracability
   :alt: GitHub

.. |maintained| image:: https://img.shields.io/badge/maintained-yes-green
   :target: https://github.com/gbene/fracability
   :alt: GitHub

.. |AGPL| image:: https://img.shields.io/badge/License-AGPL--3.0-orange.svg
   :target: https://opensource.org/license/agpl-v3/

.. |python| image:: https://img.shields.io/badge/python-3.10+-orange.svg
   :target: https://www.python.org/downloads/

.. |issues| image:: https://img.shields.io/badge/GitHub-Issues-orange?logo=github
   :target: https://github.com/gbene/FracAbility/issues

+----------------------+----------------+-------------+
| Deployment           | |pypi|         | |conda|     |
+----------------------+----------------+-------------+
| GitHub               | |maintained|   | |stars|     |
+----------------------+----------------+-------------+
| Citation             |                |             |
+----------------------+----------------+-------------+
| License              | |AGPL|         |             |
+----------------------+----------------+-------------+
| Community            | |issues|       |             |
+----------------------+----------------+-------------+


